# Overview

## Description

### Task Description

Framewise phoneme classification of TIMIT dataset  

- 1229932 training samples
- 451552 testing samples
- Evaluation metric: catagorization accuracy

### Deadlines

- **Kaggle: 2021/04/02 23:59 (UTC+8)**
- **NTU COOL: 2021/04/04 23:59 (UTC+8)**

### Notes

- Team Name: `<student_ID>_<anything>`
- If there are any questions, you may discuss with us on NTU COOL or email ( [ntu-ml-2021spring-ta@googlegroups.com](mailto:ntu-ml-2021spring-ta@googlegroups.com) with the title begining with [hw2] )

## Citation

yenmeng. (2021). ML2021Spring-hw2. Kaggle. https://kaggle.com/competitions/ml2021spring-hw2

# Data

## Dataset Description

complete data : `timit_11/`  

- training data: `training_11.npy`  
- training label: `trainin_label_11.npy`  
- testing data: `testing_label_11.npy`